@@ -9,7 +9,8 @@ class Database():
         self.status = DatabaseStatus.RUNNING.value
         self.queries = Queue()
         self.has_queries = threading.Semaphore(value=0)
-        self._is_down = threading.Lock()
+        self.status_lock = threading.Lock()
+        self.is_up=threading.Event()
         self.waiters = waiters
         self.executors = executors
         self.engine = engine
@@ -23,11 +24,11 @@ class Database():
             self.waiters[query.wait].run_query(query, self)
 
     def change_status(self, new_status):
-        with self._is_down:
+        with self.status_lock:
             self.status = new_status
 
     def check_status(self):
-        with self._is_down:
+        with self.status_lock:
             return self.status
 
 
